@@ -173,6 +173,8 @@ my %hierarchy = (
     'TintEffect' => 'ImageTransformEffect',
     'UpdateBackground' => 'Task',
     'UpdateShape' => 'Task',
+    'VbaModule' => 'ResourceBase',
+    'VbaProject' => 'ResourceBase',
     'VideoExportOptions' => 'ExportOptions',
     'VideoFrame' => 'GeometryShape',
     'ViewProperties' => 'ResourceBase',
@@ -422,6 +424,9 @@ my %determiners = (
     'TintEffect' => { 'Type' => 'Tint', },
     'UpdateBackground' => { 'Type' => 'UpdateBackground', },
     'UpdateShape' => { 'Type' => 'UpdateShape', },
+    'VbaModule' => {  },
+    'VbaProject' => {  },
+    'VbaReference' => {  },
     'VideoExportOptions' => { 'Format' => 'mpeg4', },
     'VideoFrame' => { 'Type' => 'VideoFrame', },
     'ViewProperties' => {  },
